@@ -9,6 +9,7 @@ from django.conf import settings
 from django.core.mail import EmailMultiAlternatives
 from django.utils import six
 from django.utils.datastructures import MultiValueDict
+from django.utils.encoding import force_text
 
 from djblets.mail.dmarc import is_email_allowed_by_dmarc
 from djblets.mail.utils import build_email_address_via_service
@@ -261,7 +262,7 @@ class EmailMessage(EmailMultiAlternatives):
         # when communicating with the SMTP server.
         super(EmailMessage, self).__init__(
             subject=subject,
-            body=text_body,
+            body=force_text(text_body),
             from_email=settings.DEFAULT_FROM_EMAIL,
             to=to,
             cc=cc,
@@ -279,7 +280,7 @@ class EmailMessage(EmailMultiAlternatives):
         self._headers = headers
 
         if html_body:
-            self.attach_alternative(html_body, 'text/html')
+            self.attach_alternative(force_text(html_body), 'text/html')
 
     def message(self):
         """Construct an outgoing message for the e-mail.
@@ -303,7 +304,10 @@ class EmailMessage(EmailMultiAlternatives):
 
         for name, value_list in six.iterlists(self._headers):
             for value in value_list:
-                msg.add_header(six.binary_type(name), value)
+                # Use the native string on each version of Python. These
+                # are headers, so they'll be convertible without encoding
+                # issues.
+                msg.add_header(str(name), value)
 
         return msg
 
